@@ -84,6 +84,7 @@ class WorkflowExecution(BaseModel):
     status: ExecutionStatus = Field(alias="overall_status")
     created_date: datetime = Field(alias="date")
     prompt: str
-    updated_date: Optional[datetime] = None
+    updated_date: Optional[datetime] = Field(alias="update_date")
     created_by: User
+    conversation_id: Optional[str] = None
     tokens_usage: Optional[TokensUsage] = None
